@@ -199,7 +199,7 @@ class Acido(object):
             'image_registry_username': self.image_registry_username,
             'image_registry_password': self.image_registry_password,
             'image_registry_server': self.image_registry_server,
-            'user_assigned_id': self.user_assigned_id
+            'user_assigned_id': self.user_assigned
         }
 
         try:
@@ -267,16 +267,29 @@ class Acido(object):
         if instance_num > 10:
             instance_num_groups = list(chunks(range(1, instance_num + 1), 10))
             for cg_n, ins_num in enumerate(instance_num_groups):
+                env_vars = {
+                    'RG': self.rg,
+                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
+                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+                }
                 group_name = f'{fleet_name}-{cg_n+1:02d}'
                 if group_name not in response.keys():
                     response[group_name] = []
                 last_instance = len(ins_num)
                 response[group_name] = self.instance_manager.deploy(
                                             name=group_name, 
-                                            instance_number=last_instance
+                                            instance_number=last_instance,
+                                            env_vars=env_vars
                                         )
         else:
-            response[fleet_name] = self.instance_manager.deploy(name=fleet_name, instance_number=instance_num)
+            env_vars = {
+                    'RG': self.rg,
+                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
+                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+            }
+            response[fleet_name] = self.instance_manager.deploy(name=fleet_name, instance_number=instance_num, env_vars=env_vars)
         
         if not interactive:
             return response
@@ -364,55 +377,6 @@ class Acido(object):
 
         return
 
-    def scan(self, command: list = None, instance_num: int = 3, fleet_name: str = 'acido', interactive=False):
-        response = {}
-        if instance_num > 10:
-            instance_num_groups = list(chunks(range(1, instance_num + 1), 10))
-            for cg_n, ins_num in enumerate(instance_num_groups):
-                group_name = f'{fleet_name}-{cg_n+1:02d}'
-                env_vars = {
-                    'RG': self.rg,
-                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
-                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
-                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
-                }
-                if group_name not in response.keys():
-                    response[group_name] = []
-                last_instance = len(ins_num)
-                response[group_name] = self.instance_manager.deploy(
-                                            name=group_name, 
-                                            instance_number=last_instance,
-                                            env_vars=env_vars
-                                        )
-        else:
-            env_vars = {
-                    'RG': self.rg,
-                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
-                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
-                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
-                }
-            response[fleet_name] = self.instance_manager.deploy(
-                command=command, 
-                name=fleet_name, 
-                instance_number=instance_num, 
-                env_vars=env_vars
-            )
-        
-        if not interactive:
-            return response
-        else:
-            all_names = []
-            all_groups = []
-
-            for group, inst in response.items():
-                all_groups.append(group)
-                all_names += list(inst.keys())
-
-            print(good(f"Successfully created new group/s: [ {bold(' '.join(all_groups))} ]"))
-            print(good(f"Successfully created new scan/s: [ {bold(' '.join(all_names))} ]"))
-
-            return
-
     def setup(self):
         rg = os.getenv('RG') if os.getenv('RG', None) else input(info('Please provide a Resource Group Name to deploy the ACIs: '))
         self.rg = rg
